@@ -25,8 +25,17 @@ nc_var.character <- function(x, i) {
 #'@export
 nc_var.NetCDF <- function(x, i) {
   out <- RNetCDF::var.inq.nc(x, i)
-  out$dimids <- NULL
-  faster_as_tibble(out)
+  # Convert dimids to empty vector when variable is scalar:
+  if (anyNA(out$dimids)) {
+    out$dimids <- integer(0)
+  }
+  # Store vector values as nested lists:
+  vectors <- c("dimids", "chunksizes", "filter_id", "filter_params")
+  listcols <- vectors[vectors %in% names(out)]
+  out[listcols] <- lapply(out[listcols], list)
+  # Keep only list items with length 1:
+  out <- out[lengths(out) == 1]
+  # Transform list to tibble row:
+  tibble::as_tibble_row(out)
 }
 
-
